@@ -63,7 +63,7 @@ def transform(file_name: str, cntx: dict):
 
     global context
     context = cntx
-    with open(file_name, 'r') as file, open(file_name + '_fox', 'w') as result_file:
+    with open(file_name, 'r') as file, open(file_name + '.html', 'w') as result_file:
         file_gen = (line for line in file)
         current_line = 0
         for line in file_gen:
